# Coinmarketcap Parsing

Python3 scrap all the related information about different cryptocurrencies around the [Coinmarketcap](https://coinmarketcap.com/) 

### Installation
PyPI
```
pip install package_crypto==0.0.8
```

